"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PullPaymentList = void 0;
const objects_1 = require("@hypernetlabs/objects");
const core_1 = require("@material-ui/core");
const styles_1 = require("@material-ui/core/styles");
const icons_1 = require("@material-ui/icons");
const contexts_1 = require("../../contexts");
const react_1 = __importDefault(require("react"));
const PullPaymentRow = (props) => {
    const { pullPayment, acceptPaymentButtonVisible, pullFundsButtonVisible, disputeButtonVisible, onAcceptPullPaymentClick, onDisputePullPaymentClick, onPullFundClick, publicIdentifier, } = props;
    const [open, setOpen] = react_1.default.useState(false);
    const { viewUtils, dateUtils } = contexts_1.useStoreContext();
    const StyledTableRow = styles_1.withStyles((theme) => ({
        root: {
            "&:nth-of-type(odd)": {
                backgroundColor: theme.palette.action.hover,
            },
            "& > *": {
                borderBottom: "unset",
            },
        },
    }))(core_1.TableRow);
    const renderListItem = (label, value, hideDivider) => {
        return (react_1.default.createElement(core_1.Box, { margin: 2 },
            react_1.default.createElement(core_1.ListItem, null,
                react_1.default.createElement(core_1.Box, { display: "flex", justifyContent: "space-between", width: "100%" },
                    react_1.default.createElement(core_1.Typography, { style: { fontWeight: 600, fontSize: 14 } },
                        label,
                        ":"),
                    react_1.default.createElement(core_1.Typography, { style: { fontSize: 14 } }, value))),
            !hideDivider && react_1.default.createElement(core_1.Divider, null)));
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(StyledTableRow, null,
            react_1.default.createElement(core_1.TableCell, null,
                react_1.default.createElement(core_1.IconButton, { "aria-label": "expand row", size: "small", onClick: () => setOpen(!open) }, open ? react_1.default.createElement(icons_1.KeyboardArrowUp, null) : react_1.default.createElement(icons_1.KeyboardArrowDown, null))),
            react_1.default.createElement(core_1.TableCell, { component: "th", scope: "row" }, pullPayment.merchantUrl),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pullPayment.authorizedAmount)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pullPayment.requiredStake)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pullPayment.amountTransferred)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, dateUtils.fromTimestampToUI(pullPayment.expirationDate)),
            react_1.default.createElement(core_1.TableCell, { align: "right", style: {
                    color: viewUtils.fromPaymentStateColor(pullPayment.state),
                } }, viewUtils.fromPaymentState(pullPayment.state)),
            react_1.default.createElement(core_1.TableCell, { align: "right" },
                acceptPaymentButtonVisible && (react_1.default.createElement(core_1.Button, { size: "small", variant: "outlined", color: "primary", onClick: () => onAcceptPullPaymentClick(pullPayment.id) }, "Accept")),
                disputeButtonVisible && (react_1.default.createElement(core_1.Button, { size: "small", variant: "outlined", color: "secondary", onClick: () => onDisputePullPaymentClick(pullPayment.id) }, "Dispute")),
                pullFundsButtonVisible && (react_1.default.createElement(core_1.Button, { size: "small", variant: "outlined", color: "secondary", onClick: () => onPullFundClick(pullPayment.id) }, "Pull Funds")))),
        react_1.default.createElement(core_1.TableCell, { style: { paddingBottom: 0, paddingTop: 0, borderBottom: "none" }, colSpan: 6 },
            react_1.default.createElement(core_1.Collapse, { in: open, timeout: "auto", unmountOnExit: true },
                react_1.default.createElement(core_1.Box, { marginBottom: 1 },
                    react_1.default.createElement(core_1.List, { dense: true },
                        renderListItem("Payment ID", pullPayment.id),
                        renderListItem("From", `${pullPayment.from} ${pullPayment.from === publicIdentifier ? "(You)" : ""}`),
                        renderListItem("To", `${pullPayment.to} ${pullPayment.to === publicIdentifier ? "(You)" : ""}`),
                        renderListItem("State", viewUtils.fromPaymentState(pullPayment.state)),
                        renderListItem("Payment Token", pullPayment.paymentToken),
                        renderListItem("Required Stake", viewUtils.fromBigNumberWei(pullPayment.requiredStake)),
                        renderListItem("Amount Staked	", viewUtils.fromBigNumberWei(pullPayment.amountStaked)),
                        renderListItem("Expiration Date", dateUtils.fromTimestampToUI(pullPayment.expirationDate)),
                        renderListItem("Created", dateUtils.fromTimestampToUI(pullPayment.createdTimestamp)),
                        renderListItem("Updated", dateUtils.fromTimestampToUI(pullPayment.updatedTimestamp)),
                        renderListItem("Merchant URL", pullPayment.merchantUrl),
                        renderListItem("Authorized Amount", viewUtils.fromBigNumberWei(pullPayment.authorizedAmount), true)))))));
};
const PullPaymentList = (props) => {
    const { pullPayments, publicIdentifier, onAcceptPullPaymentClick, onDisputePullPaymentClick, onPullFundClick, } = props;
    return (react_1.default.createElement(core_1.TableContainer, null,
        react_1.default.createElement(core_1.Table, { "aria-label": "collapsible table" },
            react_1.default.createElement(core_1.TableHead, null,
                react_1.default.createElement(core_1.TableRow, null,
                    react_1.default.createElement(core_1.TableCell, null),
                    react_1.default.createElement(core_1.TableCell, null, "Validator"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Authorized Amount"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Required Stake"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Amount Staked"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Expiration Date"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "State"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }))),
            react_1.default.createElement(core_1.TableBody, null, pullPayments.map((pullPayment) => (react_1.default.createElement(PullPaymentRow, { key: pullPayment.id, pullPayment: pullPayment, publicIdentifier: publicIdentifier, acceptPaymentButtonVisible: pullPayment.state === objects_1.EPaymentState.Proposed, pullFundsButtonVisible: publicIdentifier === pullPayment.to &&
                    pullPayment.state === objects_1.EPaymentState.Approved, disputeButtonVisible: publicIdentifier === pullPayment.from &&
                    pullPayment.state === objects_1.EPaymentState.Accepted, onAcceptPullPaymentClick: onAcceptPullPaymentClick, onDisputePullPaymentClick: onDisputePullPaymentClick, onPullFundClick: onPullFundClick })))))));
};
exports.PullPaymentList = PullPaymentList;
//# sourceMappingURL=PullPaymentList.js.map